Learn R Programming

fpcb (version 0.1.0)

arh_rkhs: Autoregressive Hilbertian Model using RKHS

Description

Estimates an autoregresive Hilbertian model of order 1 for functional time series. The temporal dependence is estimated in the Hilbert projection space which has a reproducing kernel as proposed in Hern<U+00E1>ndez et al (2021) <arXiv:2105.13627> and Wang et al (2020) <arXiv:2011.13993>.

Usage

arh_rkhs(fdata)

Arguments

fdata

an fdata object containing the functional objects and the lambda coefficients of the d dimensional RKHS representation.

Value

fdata

smoothed curves.

lambda_cent

centered coefficients of the d dimensional RKHS representation.

lambda_ce

average coefficients of the d dimensional RKHS representation.

rho

autocorrelation operator computed as: \(Gamma_0\)\(Psi\) = \(Gamma_1\). \(Gamma_0\) correspond to the Covariance and \(Gamma_0\) correspond to the Cross-Covariance (of lag 1) operators, both estimated using the coefficients \(lambda\).

References

N. Hern<U+00E1>ndez, J. Cugliari, J. Jacques. Simultaneous Predictive Bands for Functional Time Series using Minimum Entropy Sets. arXiv:2105.13627 (2021). D. Wang, Z. Zhao, R. Willett, C. Y. Yau, Functional autoregressive processes in reproducing kernel hilbert spaces, arXiv preprint arXiv:2011.13993 (2020).